<?php
/**
 * The application launcher
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

// Is there an application helper instance? We need the method main() for
// maining the application
$app = call_user_func_array(array(FrameworkConfiguration::getInstance()->readConfig('app_helper_class'), "getInstance"), array());

// Some sanity checks
if ((empty($app)) || (is_null($app))) {
	// Something went wrong!
	ApplicationEntryPoint::app_die(sprintf("[Main:] The application <span class=\"app_name\">%s</span> could not be launched because the helper class <span class=\"class_name\">%s</span> is not loaded.",
		$application,
		FrameworkConfiguration::getInstance()->readConfig('app_helper_class')
	));
} elseif (!is_object($app)) {
	// No object!
	ApplicationEntryPoint::app_die(sprintf("[Main:] The application <span class=\"app_name\">%s</span> could not be launched because &#39;app&#39; is not an object.",
		$application
	));
} elseif (!method_exists($app, FrameworkConfiguration::getInstance()->readConfig('entry_method'))) {
	// Method not found!
	ApplicationEntryPoint::app_die(sprintf("[Main:] The application <span class=\"app_name\">%s</span> could not be launched because the method <span class=\"method_name\">%s</span> is missing.",
		$application,
		FrameworkConfiguration::getInstance()->readConfig('entry_method')
	));
}

// Call the entry point method
try {
	// Call user function
	call_user_func_array(array($app, FrameworkConfiguration::getInstance()->readConfig('entry_method')), array());
} catch (FrameworkException  $e) {
	ApplicationEntryPoint::app_die(sprintf("[Main:] The application <span class=\"app_name\">%s</span> has been terminated due to a thrown exception: <strong>%s - %s</strong>",
		$application,
		$e->__toString(),
		$e->getMessage()
	));
}


// [EOF]
?>
